# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List
from typing_extensions import TypeAlias

from .conclusion import Conclusion

__all__ = ["ConclusionQueryResponse"]

ConclusionQueryResponse: TypeAlias = List[Conclusion]
